@@ -15,7 +15,11 @@ compile_help.text_help_format = function (x, rd) {
 }
 
 compile_help.html_help_format = function (x, rd) {
-    tools::Rd2HTML(rd, out = tempfile('Rtxt'), package = c(mock_package_name, NA_character_))
+    withCallingHandlers(
+        tools::Rd2HTML(rd, out = tempfile('Rtxt'), package = c(mock_package_name, NA_character_)),
+        message = function (.) tryInvokeRestart('muffleMessage'),
+        warning = function (.) tryInvokeRestart('muffleWarning')
+    )
 }
 
 patch_topic_name.text_help_format = function (x, file, topic) {
@@ -40,7 +44,7 @@ display_help_file.text_help_format = function (x, file, topic) {
 }
 
 display_help_file.html_help_format = function (x, file, topic) {
-    topic = sanitize_path(topic)
+    topic = sanitize_path_fragment(topic)
     port = tools::startDynamicHelp(NA)
     html_path = file.path(tempdir(), sprintf('.R/doc/html/%s.html', topic))
     dir.create(dirname(html_path), recursive = TRUE, showWarnings = FALSE)
