@@ -75,7 +75,7 @@ test_that('Forwarded S3 genetics without methods work', {
 })
 
 test_that('`is_S3_user_generic` can deal with substituted functions', {
-    expect_error(box::use(mod/issue125), regexp = NA)
+    expect_error(box::use(mod/issue125), NA)
 })
 
 test_that('nested functions are parsed correctly', {
@@ -83,3 +83,9 @@ test_that('nested functions are parsed correctly', {
     expect_false(box:::is_S3_user_generic('g', issue203))
     expect_false(box:::is_S3_user_generic('h', issue203))
 })
+
+test_that('functions with missing arguments are parsed correctly', {
+    expect_error(is_S3(quote(tag$span('foo', ))), NA)
+    expect_error(is_S3(quote(base$quote(expr =))), NA)
+    expect_error(is_S3(quote((quote)(expr =))), NA)
+})
